#
#	$Id: sysexits.sh,v 1.4 2014/11/20 16:24:54 craski-shell_86 Exp $
#
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#
# Copyright (c) 2013-2014 Craig R. Skinner <skinner@britvault.co.uk>
#
# Permission to use, copy, modify, and distribute this software for any
# purpose with or without fee is hereby granted, provided that the above
# copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
#
#-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
#


#
# OpemBSD: /usr/src/include/sysexits.h:
#


# /*	$OpenBSD: sysexits.h,v 1.5 2003/06/02 19:34:12 millert Exp $	*/
# /*	$NetBSD: sysexits.h,v 1.4 1994/10/26 00:56:33 cgd Exp $	*/
# 
# /*
#  * Copyright (c) 1987 Regents of the University of California.
#  * All rights reserved.
#  *
#  * Redistribution and use in source and binary forms, with or without
#  * modification, are permitted provided that the following conditions
#  * are met:
#  * 1. Redistributions of source code must retain the above copyright
#  *    notice, this list of conditions and the following disclaimer.
#  * 2. Redistributions in binary form must reproduce the above copyright
#  *    notice, this list of conditions and the following disclaimer in the
#  *    documentation and/or other materials provided with the distribution.
#  * 3. Neither the name of the University nor the names of its contributors
#  *    may be used to endorse or promote products derived from this software
#  *    without specific prior written permission.
#  *
#  * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
#  * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
#  * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
#  * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
#  * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
#  * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
#  * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
#  * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
#  * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
#  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
#  * SUCH DAMAGE.
#  *
#  *	@(#)sysexits.h	4.8 (Berkeley) 4/3/91
#  */
# 
#ifndef	_SYSEXITS_H_
#define	_SYSEXITS_H_
# 
# /*
#  *  SYSEXITS.H -- Exit status codes for system programs.
#  *
#  *	This include file attempts to categorize possible error
#  *	exit statuses for system programs, notably delivermail
#  *	and the Berkeley network.
#  *
#  *	Error numbers begin at EX__BASE to reduce the possibility of
#  *	clashing with other exit statuses that random programs may
#  *	already return.  The meaning of the codes is approximately
#  *	as follows:
#  *
#  *	EX_USAGE -- The command was used incorrectly, e.g., with
#  *		the wrong number of arguments, a bad flag, a bad
#  *		syntax in a parameter, or whatever.
#  *	EX_DATAERR -- The input data was incorrect in some way.
#  *		This should only be used for user's data & not
#  *		system files.
#  *	EX_NOINPUT -- An input file (not a system file) did not
#  *		exist or was not readable.  This could also include
#  *		errors like "No message" to a mailer (if it cared
#  *		to catch it).
#  *	EX_NOUSER -- The user specified did not exist.  This might
#  *		be used for mail addresses or remote logins.
#  *	EX_NOHOST -- The host specified did not exist.  This is used
#  *		in mail addresses or network requests.
#  *	EX_UNAVAILABLE -- A service is unavailable.  This can occur
#  *		if a support program or file does not exist.  This
#  *		can also be used as a catchall message when something
#  *		you wanted to do doesn't work, but you don't know
#  *		why.
#  *	EX_SOFTWARE -- An internal software error has been detected.
#  *		This should be limited to non-operating system related
#  *		errors as possible.
#  *	EX_OSERR -- An operating system error has been detected.
#  *		This is intended to be used for such things as "cannot
#  *		fork", "cannot create pipe", or the like.  It includes
#  *		things like getuid returning a user that does not
#  *		exist in the passwd file.
#  *	EX_OSFILE -- Some system file (e.g., /etc/passwd, /var/run/utmp,
#  *		etc.) does not exist, cannot be opened, or has some
#  *		sort of error (e.g., syntax error).
#  *	EX_CANTCREAT -- A (user specified) output file cannot be
#  *		created.
#  *	EX_IOERR -- An error occurred while doing I/O on some file.
#  *	EX_TEMPFAIL -- temporary failure, indicating something that
#  *		is not really an error.  In sendmail, this means
#  *		that a mailer (e.g.) could not create a connection,
#  *		and the request should be reattempted later.
#  *	EX_PROTOCOL -- the remote system returned something that
#  *		was "not possible" during a protocol exchange.
#  *	EX_NOPERM -- You did not have sufficient permission to
#  *		perform the operation.  This is not intended for
#  *		file system problems, which should use EX_NOINPUT or
#  *		EX_CANTCREAT, but rather for higher level permissions.
#  *	EX_CONFIG -- Something was found in an unconfigured or
#  *		misconfigured state.
#  */
# 


#
#define EX_OK		0	/* successful termination */
#
[[ -n ${EX_OK} ]] ||
{
	readonly EX_OK='0' && export EX_OK
}


#
#define EX__BASE	64	/* base value for error messages */
#
[[ -n ${EX__BASE} ]] ||
{
	readonly EX__BASE='64' && export EX__BASE
}


#
#define EX_USAGE	64	/* command line usage error */
#
[[ -n ${EX_USAGE} ]] ||
{
	readonly EX_USAGE='64' && export EX_USAGE
}


#
#define EX_DATAERR	65	/* data format error */
#
[[ -n ${EX_DATAERR} ]] ||
{
	readonly EX_DATAERR='65' && export EX_DATAERR
}


#
#define EX_NOINPUT	66	/* cannot open input */
#
[[ -n ${EX_NOINPUT} ]] ||
{
	readonly EX_NOINPUT='66' && export EX_NOINPUT
}


#
#define EX_NOUSER	67	/* addressee unknown */
#
[[ -n ${EX_NOUSER} ]] ||
{
	readonly EX_NOUSER='67' && export EX_NOUSER
}


#
#define EX_NOHOST	68	/* host name unknown */
#
[[ -n ${EX_NOHOST} ]] ||
{
	readonly EX_NOHOST='68' && export EX_NOHOST
}


#
#define EX_UNAVAILABLE	69	/* service unavailable */
#
[[ -n ${EX_UNAVAILABLE} ]] ||
{
	readonly EX_UNAVAILABLE='69' && export EX_UNAVAILABLE
}


#
#define EX_SOFTWARE	70	/* internal software error */
#
[[ -n ${EX_SOFTWARE} ]] ||
{
	readonly EX_SOFTWARE='70' && export EX_SOFTWARE
}


#
#define EX_OSERR	71	/* system error (e.g., can't fork) */
#
[[ -n ${EX_OSERR} ]] ||
{
	readonly EX_OSERR='71' && export EX_OSERR
}


#
#define EX_OSFILE	72	/* critical OS file missing */
#
[[ -n ${EX_OSFILE} ]] ||
{
	readonly EX_OSFILE='72' && export EX_OSFILE
}


#
#define EX_CANTCREAT	73	/* can't create (user) output file */
#
[[ -n ${EX_CANTCREAT} ]] ||
{
	readonly EX_CANTCREAT='73' && export EX_CANTCREAT
}


#
#define EX_IOERR	74	/* input/output error */
#
[[ -n ${EX_IOERR} ]] ||
{
	readonly EX_IOERR='74' && export EX_IOERR
}


#
#define EX_TEMPFAIL	75	/* temp failure; user is invited to retry */
#
[[ -n ${EX_TEMPFAIL} ]] ||
{
	readonly EX_TEMPFAIL='75' && export EX_TEMPFAIL
}


#
#define EX_PROTOCOL	76	/* remote error in protocol */
#
[[ -n ${EX_PROTOCOL} ]] ||
{
	readonly EX_PROTOCOL='76' && export EX_PROTOCOL
}


#
#define EX_NOPERM	77	/* permission denied */
#
[[ -n ${EX_NOPERM} ]] ||
{
	readonly EX_NOPERM='77' && export EX_NOPERM
}


#
#define EX_CONFIG	78	/* configuration error */
#
[[ -n ${EX_CONFIG} ]] ||
{
	readonly EX_CONFIG='78' && export EX_CONFIG
}


#
#define EX__MAX		78	/* maximum listed value */
#
[[ -n ${EX__MAX} ]] ||
{
	readonly EX__MAX='78' && export EX__MAX
}

